patch 9.2.0497: Cannot jump to remote tags

Commit: 
https://github.com/vim/vim/commit/4a99175e3949cef3ebe6a9ee6a82b963cfdf5995
Author: Miguel Barro <[email protected]>
Date:   Sun May 17 20:00:41 2026 +0000

    patch 9.2.0497: Cannot jump to remote tags
    
    Problem:  Cannot jump to remote tags
              (after v9.2.0405)
    Solution: Add the 'tagsecure' option (Miguel Barro)
    
    closes: #20162
    
    Co-authored-by: Copilot Autofix powered by AI 
<[email protected]>
    Signed-off-by: Miguel Barro <[email protected]>
    Signed-off-by: Christian Brabandt <[email protected]>

diff --git a/runtime/doc/options.txt b/runtime/doc/options.txt
index 1c1100a98..2ba59824f 100644
--- a/runtime/doc/options.txt
+++ b/runtime/doc/options.txt
@@ -9223,6 +9223,22 @@ A jump table for the options with a short description 
can be found at |Q_op|.
        file names from the list.  This avoids problems when a future version
        uses another default.
 
+                       *'tagsecure'* *'tsc'* *'notagsecure'* *'notsc'*
+'tagsecure' 'tsc'      boolean (default on)
+                       global
+       When on, Vim refuses to follow tag entries whose file field looks like
+       a URL ("scheme://..."), aborting the jump with error |E1576|.  This
+       prevents tag files from causing Vim to open URLs through |netrw|, which
+       would trigger a network request and expose netrw's URL-handling code to
+       attacker-controlled input or lead to environment exfiltration.
+
+       Tag files might be distributed alongside source code (e.g. via Git
+       repositories) and may therefore be untrustworthy.  Only disable
+       this option if you fully control the tag files Vim will read.
+
+       This option cannot be set from a |modeline| or in the |sandbox|, for
+       security reasons.
+
                                *'tagstack'* *'tgst'* *'notagstack'* *'notgst'*
 'tagstack' 'tgst'      boolean (default on)
                        global
diff --git a/runtime/doc/quickref.txt b/runtime/doc/quickref.txt
index acc5dbdd0..96bfdb7e1 100644
--- a/runtime/doc/quickref.txt
+++ b/runtime/doc/quickref.txt
@@ -1,4 +1,4 @@
-*quickref.txt* For Vim version 9.2.  Last change: 2026 Apr 21
+*quickref.txt* For Vim version 9.2.  Last change: 2026 May 17
 
 
                  VIM REFERENCE MANUAL    by Bram Moolenaar
@@ -960,6 +960,7 @@ Short explanation of each option:           *option-list*
 'taglength'      'tl'      number of significant characters for a tag
 'tagrelative'    'tr'      file names in tag file are relative
 'tags'           'tag'     list of file names used by the tag command
+'tagsecure'      'tsc'     do not open remote files using tag commands
 'tagstack'       'tgst'    push tags onto the tag stack
 'tcldll'                   name of the Tcl dynamic library
 'term'                     name of the terminal
diff --git a/runtime/doc/tags b/runtime/doc/tags
index b94169f0f..eb7e21929 100644
--- a/runtime/doc/tags
+++ b/runtime/doc/tags
@@ -785,6 +785,7 @@ $quote      eval.txt        /*$quote*
 'nota' options.txt     /*'nota'*
 'notagbsearch' options.txt     /*'notagbsearch'*
 'notagrelative'        options.txt     /*'notagrelative'*
+'notagsecure'  options.txt     /*'notagsecure'*
 'notagstack'   options.txt     /*'notagstack'*
 'notbi'        options.txt     /*'notbi'*
 'notbidi'      options.txt     /*'notbidi'*
@@ -803,6 +804,7 @@ $quote      eval.txt        /*$quote*
 'noto' options.txt     /*'noto'*
 'notop'        options.txt     /*'notop'*
 'notr' options.txt     /*'notr'*
+'notsc'        options.txt     /*'notsc'*
 'nottimeout'   options.txt     /*'nottimeout'*
 'nottybuiltin' options.txt     /*'nottybuiltin'*
 'nottyfast'    options.txt     /*'nottyfast'*
@@ -1229,6 +1231,7 @@ $quote    eval.txt        /*$quote*
 'taglength'    options.txt     /*'taglength'*
 'tagrelative'  options.txt     /*'tagrelative'*
 'tags' options.txt     /*'tags'*
+'tagsecure'    options.txt     /*'tagsecure'*
 'tagstack'     options.txt     /*'tagstack'*
 'tal'  options.txt     /*'tal'*
 'tb'   options.txt     /*'tb'*
@@ -1279,6 +1282,7 @@ $quote    eval.txt        /*$quote*
 'tr'   options.txt     /*'tr'*
 'trz'  options.txt     /*'trz'*
 'ts'   options.txt     /*'ts'*
+'tsc'  options.txt     /*'tsc'*
 'tsl'  options.txt     /*'tsl'*
 'tsr'  options.txt     /*'tsr'*
 'tsrfu'        options.txt     /*'tsrfu'*
diff --git a/runtime/doc/tagsrch.txt b/runtime/doc/tagsrch.txt
index cad4caf1a..d27838386 100644
--- a/runtime/doc/tagsrch.txt
+++ b/runtime/doc/tagsrch.txt
@@ -1,4 +1,4 @@
-*tagsrch.txt*  For Vim version 9.2.  Last change: 2026 Feb 14
+*tagsrch.txt*  For Vim version 9.2.  Last change: 2026 May 17
 
 
                  VIM REFERENCE MANUAL    by Bram Moolenaar
@@ -581,7 +581,8 @@ ctags).
                doubtful).  It cannot contain a <Tab>.
                                                                *E1576*
                Using a remote file via network protocol (e.g. using
-               http://remote/file.txt) is not allowed.
+               http://remote/file.txt) is not allowed unless 'tagsecure'
+               is unset.
 {tagaddress}   The Ex command that positions the cursor on the tag.  It can
                be any Ex command, although restrictions apply (see
                |tag-security|).  Posix only allows line numbers and search
diff --git a/runtime/doc/version9.txt b/runtime/doc/version9.txt
index a8ea821f4..846d2dfa2 100644
--- a/runtime/doc/version9.txt
+++ b/runtime/doc/version9.txt
@@ -52688,6 +52688,7 @@ Options: ~
                        configure the height.
 't_BS'                 Begin synchronized update.
 't_ES'                 End synchronized update.
+'tagsecure'            Do not open remote files using tag commands
 'termresize'           Method for handling terminal resize events.
 'termsync'             Enable support for terminal DEC 2026 sync mode.
 'winhighlight'         Window-local highlight group mappings.
diff --git a/runtime/optwin.vim b/runtime/optwin.vim
index 1ecd602d3..c926d738f 100644
--- a/runtime/optwin.vim
+++ b/runtime/optwin.vim
@@ -1,7 +1,7 @@
 " These commands create the option window.
 "
 " Maintainer:  The Vim Project <https://github.com/vim/vim>
-" Last Change: 2026 Apr 21
+" Last Change: 2026 May 17
 " Former Maintainer:   Bram Moolenaar <[email protected]>
 
 " If there already is an option window, jump to that one.
@@ -315,6 +315,8 @@ call append("$", "  " .. s:global_or_local)
 call <SID>OptionG("tc", &tc)
 call <SID>AddOption("tagrelative", gettext("file names in a tags file are 
relative to the tags file"))
 call <SID>BinOptionG("tr", &tr)
+call <SID>AddOption("tagsecure", gettext("a :tag command cannot access remote 
files"))
+call <SID>BinOptionG("tsc", &tsc)
 call <SID>AddOption("tagstack", gettext("a :tag command will use the 
tagstack"))
 call <SID>BinOptionG("tgst", &tgst)
 call <SID>AddOption("showfulltag", gettext("when completing tags in Insert 
mode show more info"))
diff --git a/runtime/syntax/vim.vim b/runtime/syntax/vim.vim
index f6b137f52..4c2c137a0 100644
--- a/runtime/syntax/vim.vim
+++ b/runtime/syntax/vim.vim
@@ -70,23 +70,23 @@ syn keyword vimOption contained efm errorformat ek esckeys 
ei eventignore eiw ev
 syn keyword vimOption contained hi history hk hkmap hkp hkmapp hls hlsearch 
icon iconstring ic ignorecase imaf imactivatefunc imak imactivatekey imc 
imcmdline imd imdisable imi iminsert ims imsearch imsf imstatusfunc imst 
imstyle inc include inex includeexpr is incsearch inde indentexpr indk 
indentkeys inf infercase im insertmode isf isfname isi isident isk iskeyword 
isp isprint js joinspaces jop jumpoptions key kmp keymap km keymodel kpc 
keyprotocol kp keywordprg lmap langmap lm langmenu lnr langnoremap lrm 
langremap ls laststatus lz lazyredraw lhi lhistory lbr linebreak lines lsp 
linespace lisp lop lispoptions lw lispwords list lcs listchars lpl loadplugins 
luadll magic mef makeef menc makeencoding mp makeprg mps matchpairs mat 
matchtime mco maxcombine mfd maxfuncdepth skipwhite 
nextgroup=vimSetEqual,vimSetMod
 syn keyword vimOption contained mmd maxmapdepth mm maxmem mmp maxmempattern 
mmt maxmemtot msc maxsearchcount mis menuitems mopt messagesopt msm mkspellmem 
ml modeline mle modelineexpr mls modelines mlst modelinestrict ma modifiable 
mod modified more mouse mousef mousefocus mh mousehide mousem mousemodel 
mousemev mousemoveevent mouses mouseshape mouset mousetime mzq mzquantum 
mzschemedll mzschemegcdll nf nrformats nu number nuw numberwidth ofu omnifunc 
odev opendevice opfunc operatorfunc ost osctimeoutlen pp packpath para 
paragraphs paste pt pastetoggle pex patchexpr pm patchmode pa path perldll pi 
preserveindent pvh previewheight pvp previewpopup pvw previewwindow pdev 
printdevice penc printencoding pexpr printexpr pfn printfont pheader 
printheader pmbcs printmbcharset skipwhite nextgroup=vimSetEqual,vimSetMod
 syn keyword vimOption contained pmbfn printmbfont popt printoptions prompt pb 
pumborder ph pumheight pmw pummaxwidth pumopt pw pumwidth pythondll pythonhome 
pythonthreedll pythonthreehome pyx pyxversion qftf quickfixtextfunc qe 
quoteescape ro readonly rdt redrawtime re regexpengine rnu relativenumber remap 
rop renderoptions report rs restorescreen ri revins rl rightleft rlc 
rightleftcmd rubydll ru ruler ruf rulerformat rtp runtimepath scr scroll scb 
scrollbind scf scrollfocus sj scrolljump so scrolloff sop scrolloffpad sbo 
scrollopt sect sections secure sel selection slm selectmode ssop sessionoptions 
sh shell shcf shellcmdflag sp shellpipe shq shellquote srr shellredir ssl 
shellslash stmp shelltemp st shelltype sxe shellxescape sxq shellxquote sr 
shiftround sw shiftwidth skipwhite nextgroup=vimSetEqual,vimSetMod
-syn keyword vimOption contained shm shortmess sn shortname sbr showbreak sc 
showcmd sloc showcmdloc sft showfulltag sm showmatch smd showmode stal 
showtabline stpl showtabpanel ss sidescroll siso sidescrolloff scl signcolumn 
scs smartcase si smartindent sta smarttab sms smoothscroll sts softtabstop 
spell spc spellcapcheck spf spellfile spl spelllang spo spelloptions sps 
spellsuggest sb splitbelow spk splitkeep spr splitright sol startofline stl 
statusline stlo statuslineopt su suffixes sua suffixesadd swf swapfile sws 
swapsync swb switchbuf smc synmaxcol syn syntax tcl tabclose tal tabline tpm 
tabpagemax tpl tabpanel tplo tabpanelopt ts tabstop tbs tagbsearch tc tagcase 
tfu tagfunc tl taglength tr tagrelative tag tags tgst tagstack tcldll term 
tbidi termbidi tenc termencoding skipwhite nextgroup=vimSetEqual,vimSetMod
-syn keyword vimOption contained tgc termguicolors trz termresize tsy termsync 
twk termwinkey twsl termwinscroll tws termwinsize twt termwintype terse ta 
textauto tx textmode tw textwidth tsr thesaurus tsrfu thesaurusfunc top tildeop 
to timeout tm timeoutlen title titlelen titleold titlestring tb toolbar tbis 
toolbariconsize ttimeout ttm ttimeoutlen tbi ttybuiltin tf ttyfast ttym 
ttymouse tsl ttyscroll tty ttytype udir undodir udf undofile ul undolevels ur 
undoreload uc updatecount ut updatetime vsts varsofttabstop vts vartabstop vbs 
verbose vfile verbosefile vdir viewdir vop viewoptions vi viminfo vif 
viminfofile ve virtualedit vb visualbell warn wiv weirdinvert ww whichwrap wc 
wildchar wcm wildcharm wig wildignore wic wildignorecase wmnu wildmenu wim 
wildmode skipwhite nextgroup=vimSetEqual,vimSetMod
-syn keyword vimOption contained wop wildoptions wak winaltkeys wcr wincolor wi 
window wfb winfixbuf wfh winfixheight wfw winfixwidth wh winheight whl 
winhighlight wmh winminheight wmw winminwidth winptydll wiw winwidth wse wlseat 
wtm wltimeoutlen wrap wm wrapmargin ws wrapscan write wa writeany wb 
writebackup wd writedelay xtermcodes skipwhite nextgroup=vimSetEqual,vimSetMod
+syn keyword vimOption contained shm shortmess sn shortname sbr showbreak sc 
showcmd sloc showcmdloc sft showfulltag sm showmatch smd showmode stal 
showtabline stpl showtabpanel ss sidescroll siso sidescrolloff scl signcolumn 
scs smartcase si smartindent sta smarttab sms smoothscroll sts softtabstop 
spell spc spellcapcheck spf spellfile spl spelllang spo spelloptions sps 
spellsuggest sb splitbelow spk splitkeep spr splitright sol startofline stl 
statusline stlo statuslineopt su suffixes sua suffixesadd swf swapfile sws 
swapsync swb switchbuf smc synmaxcol syn syntax tcl tabclose tal tabline tpm 
tabpagemax tpl tabpanel tplo tabpanelopt ts tabstop tbs tagbsearch tc tagcase 
tfu tagfunc tl taglength tr tagrelative tag tags tsc tagsecure tgst tagstack 
tcldll term tbidi termbidi skipwhite nextgroup=vimSetEqual,vimSetMod
+syn keyword vimOption contained tenc termencoding tgc termguicolors trz 
termresize tsy termsync twk termwinkey twsl termwinscroll tws termwinsize twt 
termwintype terse ta textauto tx textmode tw textwidth tsr thesaurus tsrfu 
thesaurusfunc top tildeop to timeout tm timeoutlen title titlelen titleold 
titlestring tb toolbar tbis toolbariconsize ttimeout ttm ttimeoutlen tbi 
ttybuiltin tf ttyfast ttym ttymouse tsl ttyscroll tty ttytype udir undodir udf 
undofile ul undolevels ur undoreload uc updatecount ut updatetime vsts 
varsofttabstop vts vartabstop vbs verbose vfile verbosefile vdir viewdir vop 
viewoptions vi viminfo vif viminfofile ve virtualedit vb visualbell warn wiv 
weirdinvert ww whichwrap wc wildchar wcm wildcharm wig wildignore wic 
wildignorecase wmnu wildmenu skipwhite nextgroup=vimSetEqual,vimSetMod
+syn keyword vimOption contained wim wildmode wop wildoptions wak winaltkeys 
wcr wincolor wi window wfb winfixbuf wfh winfixheight wfw winfixwidth wh 
winheight whl winhighlight wmh winminheight wmw winminwidth winptydll wiw 
winwidth wse wlseat wtm wltimeoutlen wrap wm wrapmargin ws wrapscan write wa 
writeany wb writebackup wd writedelay xtermcodes skipwhite 
nextgroup=vimSetEqual,vimSetMod
 
 " vimOptions: These are the turn-off setting variants {{{2
 " GEN_SYN_VIM: vimOption turn-off, START_STR='syn keyword vimOption 
contained', END_STR=''
 syn keyword vimOption contained noari noallowrevins noarab noarabic noarshape 
noarabicshape noacd noautochdir noac noautocomplete noai noautoindent noar 
noautoread noasd noautoshelldir noaw noautowrite noawa noautowriteall nobk 
nobackup nobeval noballooneval nobevalterm noballoonevalterm nobin nobinary 
nobomb nobri nobreakindent nobl nobuflisted nocdh nocdhome nocin nocindent nocp 
nocompatible nocf noconfirm noci nocopyindent nocsre nocscoperelative nocst 
nocscopetag nocsverb nocscopeverbose nocrb nocursorbind nocuc nocursorcolumn 
nocul nocursorline nodeco nodelcombine nodiff nodg nodigraph noed 
noedcompatible noemo noemoji noeof noendoffile noeol noendofline noea 
noequalalways noeb noerrorbells noek noesckeys noet noexpandtab noex noexrc 
nofic nofileignorecase
 syn keyword vimOption contained nofixeol nofixendofline nofen nofoldenable 
nofs nofsync nogd nogdefault noguipty nohid nohidden nohk nohkmap nohkp 
nohkmapp nohls nohlsearch noicon noic noignorecase noimc noimcmdline noimd 
noimdisable nois noincsearch noinf noinfercase noim noinsertmode nojs 
nojoinspaces nolnr nolangnoremap nolrm nolangremap nolz nolazyredraw nolbr 
nolinebreak nolisp nolist nolpl noloadplugins nomagic noml nomodeline nomle 
nomodelineexpr nomlst nomodelinestrict noma nomodifiable nomod nomodified 
nomore nomousef nomousefocus nomh nomousehide nomousemev nomousemoveevent nonu 
nonumber noodev noopendevice nopaste nopi nopreserveindent nopvw 
nopreviewwindow noprompt noro noreadonly nornu norelativenumber noremap nors 
norestorescreen nori norevins norl norightleft
-syn keyword vimOption contained noru noruler noscb noscrollbind noscf 
noscrollfocus nosecure nossl noshellslash nostmp noshelltemp nosr noshiftround 
nosn noshortname nosc noshowcmd nosft noshowfulltag nosm noshowmatch nosmd 
noshowmode noscs nosmartcase nosi nosmartindent nosta nosmarttab nosms 
nosmoothscroll nospell nosb nosplitbelow nospr nosplitright nosol nostartofline 
noswf noswapfile notbs notagbsearch notr notagrelative notgst notagstack 
notbidi notermbidi notgc notermguicolors notsy notermsync noterse nota 
notextauto notx notextmode notop notildeop noto notimeout notitle nottimeout 
notbi nottybuiltin notf nottyfast noudf noundofile novb novisualbell nowarn 
nowiv noweirdinvert nowic nowildignorecase nowmnu nowildmenu nowfb nowinfixbuf 
nowfh nowinfixheight
+syn keyword vimOption contained noru noruler noscb noscrollbind noscf 
noscrollfocus nosecure nossl noshellslash nostmp noshelltemp nosr noshiftround 
nosn noshortname nosc noshowcmd nosft noshowfulltag nosm noshowmatch nosmd 
noshowmode noscs nosmartcase nosi nosmartindent nosta nosmarttab nosms 
nosmoothscroll nospell nosb nosplitbelow nospr nosplitright nosol nostartofline 
noswf noswapfile notbs notagbsearch notr notagrelative notsc notagsecure notgst 
notagstack notbidi notermbidi notgc notermguicolors notsy notermsync noterse 
nota notextauto notx notextmode notop notildeop noto notimeout notitle 
nottimeout notbi nottybuiltin notf nottyfast noudf noundofile novb novisualbell 
nowarn nowiv noweirdinvert nowic nowildignorecase nowmnu nowildmenu nowfb 
nowinfixbuf nowfh nowinfixheight
 syn keyword vimOption contained nowfw nowinfixwidth nowrap nows nowrapscan 
nowrite nowa nowriteany nowb nowritebackup noxtermcodes
 
 " vimOptions: These are the invertible variants {{{2
 " GEN_SYN_VIM: vimOption invertible, START_STR='syn keyword vimOption 
contained', END_STR=''
 syn keyword vimOption contained invari invallowrevins invarab invarabic 
invarshape invarabicshape invacd invautochdir invac invautocomplete invai 
invautoindent invar invautoread invasd invautoshelldir invaw invautowrite 
invawa invautowriteall invbk invbackup invbeval invballooneval invbevalterm 
invballoonevalterm invbin invbinary invbomb invbri invbreakindent invbl 
invbuflisted invcdh invcdhome invcin invcindent invcp invcompatible invcf 
invconfirm invci invcopyindent invcsre invcscoperelative invcst invcscopetag 
invcsverb invcscopeverbose invcrb invcursorbind invcuc invcursorcolumn invcul 
invcursorline invdeco invdelcombine invdiff invdg invdigraph inved 
invedcompatible invemo invemoji inveof invendoffile inveol invendofline invea 
invequalalways inveb inverrorbells
 syn keyword vimOption contained invek invesckeys invet invexpandtab invex 
invexrc invfic invfileignorecase invfixeol invfixendofline invfen invfoldenable 
invfs invfsync invgd invgdefault invguipty invhid invhidden invhk invhkmap 
invhkp invhkmapp invhls invhlsearch invicon invic invignorecase invimc 
invimcmdline invimd invimdisable invis invincsearch invinf invinfercase invim 
invinsertmode invjs invjoinspaces invlnr invlangnoremap invlrm invlangremap 
invlz invlazyredraw invlbr invlinebreak invlisp invlist invlpl invloadplugins 
invmagic invml invmodeline invmle invmodelineexpr invmlst invmodelinestrict 
invma invmodifiable invmod invmodified invmore invmousef invmousefocus invmh 
invmousehide invmousemev invmousemoveevent invnu invnumber invodev 
invopendevice invpaste
-syn keyword vimOption contained invpi invpreserveindent invpvw 
invpreviewwindow invprompt invro invreadonly invrnu invrelativenumber invremap 
invrs invrestorescreen invri invrevins invrl invrightleft invru invruler invscb 
invscrollbind invscf invscrollfocus invsecure invssl invshellslash invstmp 
invshelltemp invsr invshiftround invsn invshortname invsc invshowcmd invsft 
invshowfulltag invsm invshowmatch invsmd invshowmode invscs invsmartcase invsi 
invsmartindent invsta invsmarttab invsms invsmoothscroll invspell invsb 
invsplitbelow invspr invsplitright invsol invstartofline invswf invswapfile 
invtbs invtagbsearch invtr invtagrelative invtgst invtagstack invtbidi 
invtermbidi invtgc invtermguicolors invtsy invtermsync invterse invta 
invtextauto invtx invtextmode
-syn keyword vimOption contained invtop invtildeop invto invtimeout invtitle 
invttimeout invtbi invttybuiltin invtf invttyfast invudf invundofile invvb 
invvisualbell invwarn invwiv invweirdinvert invwic invwildignorecase invwmnu 
invwildmenu invwfb invwinfixbuf invwfh invwinfixheight invwfw invwinfixwidth 
invwrap invws invwrapscan invwrite invwa invwriteany invwb invwritebackup 
invxtermcodes
+syn keyword vimOption contained invpi invpreserveindent invpvw 
invpreviewwindow invprompt invro invreadonly invrnu invrelativenumber invremap 
invrs invrestorescreen invri invrevins invrl invrightleft invru invruler invscb 
invscrollbind invscf invscrollfocus invsecure invssl invshellslash invstmp 
invshelltemp invsr invshiftround invsn invshortname invsc invshowcmd invsft 
invshowfulltag invsm invshowmatch invsmd invshowmode invscs invsmartcase invsi 
invsmartindent invsta invsmarttab invsms invsmoothscroll invspell invsb 
invsplitbelow invspr invsplitright invsol invstartofline invswf invswapfile 
invtbs invtagbsearch invtr invtagrelative invtsc invtagsecure invtgst 
invtagstack invtbidi invtermbidi invtgc invtermguicolors invtsy invtermsync 
invterse invta invtextauto
+syn keyword vimOption contained invtx invtextmode invtop invtildeop invto 
invtimeout invtitle invttimeout invtbi invttybuiltin invtf invttyfast invudf 
invundofile invvb invvisualbell invwarn invwiv invweirdinvert invwic 
invwildignorecase invwmnu invwildmenu invwfb invwinfixbuf invwfh 
invwinfixheight invwfw invwinfixwidth invwrap invws invwrapscan invwrite invwa 
invwriteany invwb invwritebackup invxtermcodes
 " termcap codes (which can also be set) {{{2
 " GEN_SYN_VIM: vimOption term output code, START_STR='syn keyword vimOption 
contained', END_STR='skipwhite nextgroup=vimSetEqual,vimSetMod'
 syn keyword vimOption contained t_AB t_AF t_AU t_AL t_al t_bc t_BE t_BD t_cd 
t_ce t_Ce t_CF t_cl t_cm t_Co t_CS t_Cs t_cs t_CV t_da t_db t_DL t_dl t_ds t_Ds 
t_EC t_EI t_fs t_fd t_fe t_GP t_IE t_IS t_ke t_ks t_le t_mb t_md t_me t_mr t_ms 
t_nd t_op t_RF t_RB t_RC t_RI t_Ri t_RK t_RS t_RT t_RV t_Sb t_SC t_se t_Sf t_SH 
t_SI t_Si t_so t_SR t_sr t_ST t_Te t_te t_TE t_ti t_TI t_Ts t_ts t_u7 t_ue t_us 
t_Us t_ut t_vb t_ve t_vi t_VS t_vs t_WP t_WS t_XM t_xn t_xs t_ZH t_ZR t_8f t_8b 
t_8u t_xo t_BS t_ES skipwhite nextgroup=vimSetEqual,vimSetMod
@@ -109,9 +109,9 @@ syn keyword vimOptionVarName contained efm errorformat ek 
esckeys ei eventignore
 syn keyword vimOptionVarName contained hi history hk hkmap hkp hkmapp hls 
hlsearch icon iconstring ic ignorecase imaf imactivatefunc imak imactivatekey 
imc imcmdline imd imdisable imi iminsert ims imsearch imsf imstatusfunc imst 
imstyle inc include inex includeexpr is incsearch inde indentexpr indk 
indentkeys inf infercase im insertmode isf isfname isi isident isk iskeyword 
isp isprint js joinspaces jop jumpoptions key kmp keymap km keymodel kpc 
keyprotocol kp keywordprg lmap langmap lm langmenu lnr langnoremap lrm 
langremap ls laststatus lz lazyredraw lhi lhistory lbr linebreak lines lsp 
linespace lisp lop lispoptions lw lispwords list lcs listchars lpl loadplugins 
luadll magic mef makeef menc makeencoding mp makeprg mps matchpairs mat 
matchtime mco maxcombine
 syn keyword vimOptionVarName contained mfd maxfuncdepth mmd maxmapdepth mm 
maxmem mmp maxmempattern mmt maxmemtot msc maxsearchcount mis menuitems mopt 
messagesopt msm mkspellmem ml modeline mle modelineexpr mls modelines mlst 
modelinestrict ma modifiable mod modified more mouse mousef mousefocus mh 
mousehide mousem mousemodel mousemev mousemoveevent mouses mouseshape mouset 
mousetime mzq mzquantum mzschemedll mzschemegcdll nf nrformats nu number nuw 
numberwidth ofu omnifunc odev opendevice opfunc operatorfunc ost osctimeoutlen 
pp packpath para paragraphs paste pt pastetoggle pex patchexpr pm patchmode pa 
path perldll pi preserveindent pvh previewheight pvp previewpopup pvw 
previewwindow pdev printdevice penc printencoding pexpr printexpr pfn printfont 
pheader printheader
 syn keyword vimOptionVarName contained pmbcs printmbcharset pmbfn printmbfont 
popt printoptions prompt pb pumborder ph pumheight pmw pummaxwidth pumopt pw 
pumwidth pythondll pythonhome pythonthreedll pythonthreehome pyx pyxversion 
qftf quickfixtextfunc qe quoteescape ro readonly rdt redrawtime re regexpengine 
rnu relativenumber remap rop renderoptions report rs restorescreen ri revins rl 
rightleft rlc rightleftcmd rubydll ru ruler ruf rulerformat rtp runtimepath scr 
scroll scb scrollbind scf scrollfocus sj scrolljump so scrolloff sop 
scrolloffpad sbo scrollopt sect sections secure sel selection slm selectmode 
ssop sessionoptions sh shell shcf shellcmdflag sp shellpipe shq shellquote srr 
shellredir ssl shellslash stmp shelltemp st shelltype sxe shellxescape sxq 
shellxquote
-syn keyword vimOptionVarName contained sr shiftround sw shiftwidth shm 
shortmess sn shortname sbr showbreak sc showcmd sloc showcmdloc sft showfulltag 
sm showmatch smd showmode stal showtabline stpl showtabpanel ss sidescroll siso 
sidescrolloff scl signcolumn scs smartcase si smartindent sta smarttab sms 
smoothscroll sts softtabstop spell spc spellcapcheck spf spellfile spl 
spelllang spo spelloptions sps spellsuggest sb splitbelow spk splitkeep spr 
splitright sol startofline stl statusline stlo statuslineopt su suffixes sua 
suffixesadd swf swapfile sws swapsync swb switchbuf smc synmaxcol syn syntax 
tcl tabclose tal tabline tpm tabpagemax tpl tabpanel tplo tabpanelopt ts 
tabstop tbs tagbsearch tc tagcase tfu tagfunc tl taglength tr tagrelative tag 
tags tgst tagstack
-syn keyword vimOptionVarName contained tcldll term tbidi termbidi tenc 
termencoding tgc termguicolors trz termresize tsy termsync twk termwinkey twsl 
termwinscroll tws termwinsize twt termwintype terse ta textauto tx textmode tw 
textwidth tsr thesaurus tsrfu thesaurusfunc top tildeop to timeout tm 
timeoutlen title titlelen titleold titlestring tb toolbar tbis toolbariconsize 
ttimeout ttm ttimeoutlen tbi ttybuiltin tf ttyfast ttym ttymouse tsl ttyscroll 
tty ttytype udir undodir udf undofile ul undolevels ur undoreload uc 
updatecount ut updatetime vsts varsofttabstop vts vartabstop vbs verbose vfile 
verbosefile vdir viewdir vop viewoptions vi viminfo vif viminfofile ve 
virtualedit vb visualbell warn wiv weirdinvert ww whichwrap wc wildchar wcm 
wildcharm wig wildignore
-syn keyword vimOptionVarName contained wic wildignorecase wmnu wildmenu wim 
wildmode wop wildoptions wak winaltkeys wcr wincolor wi window wfb winfixbuf 
wfh winfixheight wfw winfixwidth wh winheight whl winhighlight wmh winminheight 
wmw winminwidth winptydll wiw winwidth wse wlseat wtm wltimeoutlen wrap wm 
wrapmargin ws wrapscan write wa writeany wb writebackup wd writedelay xtermcodes
+syn keyword vimOptionVarName contained sr shiftround sw shiftwidth shm 
shortmess sn shortname sbr showbreak sc showcmd sloc showcmdloc sft showfulltag 
sm showmatch smd showmode stal showtabline stpl showtabpanel ss sidescroll siso 
sidescrolloff scl signcolumn scs smartcase si smartindent sta smarttab sms 
smoothscroll sts softtabstop spell spc spellcapcheck spf spellfile spl 
spelllang spo spelloptions sps spellsuggest sb splitbelow spk splitkeep spr 
splitright sol startofline stl statusline stlo statuslineopt su suffixes sua 
suffixesadd swf swapfile sws swapsync swb switchbuf smc synmaxcol syn syntax 
tcl tabclose tal tabline tpm tabpagemax tpl tabpanel tplo tabpanelopt ts 
tabstop tbs tagbsearch tc tagcase tfu tagfunc tl taglength tr tagrelative tag 
tags tsc tagsecure
+syn keyword vimOptionVarName contained tgst tagstack tcldll term tbidi 
termbidi tenc termencoding tgc termguicolors trz termresize tsy termsync twk 
termwinkey twsl termwinscroll tws termwinsize twt termwintype terse ta textauto 
tx textmode tw textwidth tsr thesaurus tsrfu thesaurusfunc top tildeop to 
timeout tm timeoutlen title titlelen titleold titlestring tb toolbar tbis 
toolbariconsize ttimeout ttm ttimeoutlen tbi ttybuiltin tf ttyfast ttym 
ttymouse tsl ttyscroll tty ttytype udir undodir udf undofile ul undolevels ur 
undoreload uc updatecount ut updatetime vsts varsofttabstop vts vartabstop vbs 
verbose vfile verbosefile vdir viewdir vop viewoptions vi viminfo vif 
viminfofile ve virtualedit vb visualbell warn wiv weirdinvert ww whichwrap wc 
wildchar wcm wildcharm
+syn keyword vimOptionVarName contained wig wildignore wic wildignorecase wmnu 
wildmenu wim wildmode wop wildoptions wak winaltkeys wcr wincolor wi window wfb 
winfixbuf wfh winfixheight wfw winfixwidth wh winheight whl winhighlight wmh 
winminheight wmw winminwidth winptydll wiw winwidth wse wlseat wtm wltimeoutlen 
wrap wm wrapmargin ws wrapscan write wa writeany wb writebackup wd writedelay 
xtermcodes
 " GEN_SYN_VIM: vimOption term output code variable, START_STR='syn keyword 
vimOptionVarName contained', END_STR=''
 syn keyword vimOptionVarName contained t_AB t_AF t_AU t_AL t_al t_bc t_BE t_BD 
t_cd t_ce t_Ce t_CF t_cl t_cm t_Co t_CS t_Cs t_cs t_CV t_da t_db t_DL t_dl t_ds 
t_Ds t_EC t_EI t_fs t_fd t_fe t_GP t_IE t_IS t_ke t_ks t_le t_mb t_md t_me t_mr 
t_ms t_nd t_op t_RF t_RB t_RC t_RI t_Ri t_RK t_RS t_RT t_RV t_Sb t_SC t_se t_Sf 
t_SH t_SI t_Si t_so t_SR t_sr t_ST t_Te t_te t_TE t_ti t_TI t_Ts t_ts t_u7 t_ue 
t_us t_Us t_ut t_vb t_ve t_vi t_VS t_vs t_WP t_WS t_XM t_xn t_xs t_ZH t_ZR t_8f 
t_8b t_8u t_xo t_BS t_ES
 syn keyword vimOptionVarName contained t_F1 t_F2 t_F3 t_F4 t_F5 t_F6 t_F7 t_F8 
t_F9 t_k1 t_K1 t_k2 t_k3 t_K3 t_k4 t_K4 t_k5 t_K5 t_k6 t_K6 t_k7 t_K7 t_k8 t_K8 
t_k9 t_K9 t_KA t_kb t_kB t_KB t_KC t_kd t_kD t_KD t_KE t_KF t_KG t_kh t_KH t_kI 
t_KI t_KJ t_KK t_kl t_KL t_kN t_kP t_kr t_ku
diff --git a/src/option.h b/src/option.h
index a4359a259..c3df71fca 100644
--- a/src/option.h
+++ b/src/option.h
@@ -1030,6 +1030,7 @@ EXTERN unsigned tc_flags;       // flags from 'tagcase'
 EXTERN long    p_tl;           // 'taglength'
 EXTERN int     p_tr;           // 'tagrelative'
 EXTERN char_u  *p_tags;        // 'tags'
+EXTERN int     p_tagsecure;    // 'tagsecure'
 EXTERN int     p_tgst;         // 'tagstack'
 #if defined(DYNAMIC_TCL)
 EXTERN char_u  *p_tcldll;      // 'tcldll'
diff --git a/src/optiondefs.h b/src/optiondefs.h
index af556569e..f238209a7 100644
--- a/src/optiondefs.h
+++ b/src/optiondefs.h
@@ -2638,6 +2638,9 @@ static struct vimoption options[] =
                            (char_u *)"./tags,tags",
 #endif
                                (char_u *)0L} SCTX_INIT},
+    {"tagsecure",   "tsc",   P_BOOL|P_VI_DEF|P_SECURE,
+                           (char_u *)&p_tagsecure, PV_NONE, NULL, NULL,
+                           {(char_u *)TRUE, (char_u *)TRUE} SCTX_INIT},
     {"tagstack",    "tgst", P_BOOL|P_VI_DEF,
                            (char_u *)&p_tgst, PV_NONE, NULL, NULL,
                            {(char_u *)TRUE, (char_u *)0L} SCTX_INIT},
diff --git a/src/po/vim.pot b/src/po/vim.pot
index 3c0746495..f1369d68a 100644
--- a/src/po/vim.pot
+++ b/src/po/vim.pot
@@ -8,7 +8,7 @@ msgid ""
 msgstr ""
 "Project-Id-Version: Vim
"
 "Report-Msgid-Bugs-To: [email protected]
"
-"POT-Creation-Date: 2026-05-15 16:34+0000
"
+"POT-Creation-Date: 2026-05-17 19:50+0000
"
 "PO-Revision-Date: YEAR-MO-DA HO:MI+ZONE
"
 "Last-Translator: FULL NAME <EMAIL@ADDRESS>
"
 "Language-Team: LANGUAGE <[email protected]>
"
@@ -9349,6 +9349,9 @@ msgstr ""
 msgid "file names in a tags file are relative to the tags file"
 msgstr ""
 
+msgid "a :tag command cannot access remote files"
+msgstr ""
+
 msgid "a :tag command will use the tagstack"
 msgstr ""
 
diff --git a/src/testdir/test_options.vim b/src/testdir/test_options.vim
index 340ca3641..d9ca39634 100644
--- a/src/testdir/test_options.vim
+++ b/src/testdir/test_options.vim
@@ -318,7 +318,7 @@ func Test_set_completion()
 
   " Expand abbreviation of options.
   call feedkeys(":set ts\<C-A>\<C-B>\"\<CR>", 'tx')
-  call assert_equal('"set tabstop termsync thesaurus thesaurusfunc ttyscroll', 
@:)
+  call assert_equal('"set tabstop tagsecure termsync thesaurus thesaurusfunc 
ttyscroll', @:)
 
   " Expand current value
   call feedkeys(":set suffixes=\<C-A>\<C-B>\"\<CR>", 'tx')
@@ -1696,7 +1696,7 @@ endfunc
 
 " Test for changing options in a sandbox
 func Test_opt_sandbox()
-  for opt in ['backupdir', 'cdpath', 'exrc', 'findfunc']
+  for opt in ['backupdir', 'cdpath', 'exrc', 'findfunc', 'tagsecure']
     call assert_fails('sandbox set ' .. opt .. '?', 'E48:')
     call assert_fails('sandbox let &' .. opt .. ' = 1', 'E48:')
   endfor
diff --git a/src/testdir/test_tagjump.vim b/src/testdir/test_tagjump.vim
index d0e18002b..7df75cff5 100644
--- a/src/testdir/test_tagjump.vim
+++ b/src/testdir/test_tagjump.vim
@@ -1719,10 +1719,23 @@ func Test_tagjump_refuse_url()
   call writefile([
         \ "XTagURL     http://127.0.0.1:1/$XTAG_SECRET/file.c  /^int main"
         \ ], 'Xtags', 'D')
+  let save_tagsecure = &tagsecure
   let save_tags = &tags
   set tags=Xtags
 
+  " E1576: Tag file entry must not be a URL
+  set tagsecure
   call assert_fails('tag XTagURL', 'E1576:')
+  set tsc
+  call assert_fails('tag XTagURL', 'E1576:')
+
+  " E429: File does not exist
+  set notagsecure
+  call assert_fails('tag XTagURL', 'E429:')
+  set notsc
+  call assert_fails('tag XTagURL', 'E429:')
+
+  let &tagsecure = save_tagsecure
   let &tags = save_tags
 endfunc
 
diff --git a/src/version.c b/src/version.c
index 2e76cbe48..2eaaa4562 100644
--- a/src/version.c
+++ b/src/version.c
@@ -729,6 +729,8 @@ static char *(features[]) =
 
 static int included_patches[] =
 {   /* Add new patch number below this line */
+/**/
+    497,
 /**/
     496,
 /**/

diff --git a/src/tag.c b/src/tag.c
index 6861a44cf..24d33bc11 100644
--- a/src/tag.c
+++ b/src/tag.c
@@ -4135,10 +4135,10 @@ expand_tag_fname(char_u *fname, char_u *tag_fname, int 
expand)
     char_u     *expanded_fname = NULL;
     expand_T   xpc;
 
-    // Refuse to follow URLs from tag files.  Tag entries are expected
-    // to reference local source files; a URL would otherwise be passed
-    // to netrw and trigger a network request.
-    if (path_with_url(fname))
+    // Refuse to follow URLs from tag files unless 'tagsecure' is false.
+    // Tag entries are expected to reference local source files; a URL would
+    // otherwise be passed to netrw and trigger a network request.
+    if (p_tagsecure && path_with_url(fname))
     {
        emsg(_(e_tag_file_entry_must_not_be_url));
        return NULL;
-- 
-- 
You received this message from the "vim_dev" maillist.
Do not top-post! Type your reply below the text you are replying to.
For more information, visit http://www.vim.org/maillist.php

--- 
You received this message because you are subscribed to the Google Groups 
"vim_dev" group.
To unsubscribe from this group and stop receiving emails from it, send an email 
to [email protected].
To view this discussion visit 
https://groups.google.com/d/msgid/vim_dev/E1wOi7g-00A5cR-Ff%40256bit.org.

Raspunde prin e-mail lui